fields module
=============

.. automodule:: whoosh.fields

Schema class
------------

.. autoclass:: Schema
    :members:

FieldType base class
---------------------

.. autoclass:: FieldType
    :members:
    
Pre-made field types
--------------------

.. autoclass:: ID
.. autoclass:: IDLIST
.. autoclass:: STORED
.. autoclass:: KEYWORD
.. autoclass:: TEXT
.. autoclass:: NGRAM

Formats
-------

.. autoclass:: Format
    :members:

.. autoclass:: Stored
.. autoclass:: Existence
.. autoclass:: Frequency
.. autoclass:: DocBoosts
.. autoclass:: Positions
.. autoclass:: Characters
.. autoclass:: PositionBoosts
.. autoclass:: CharacterBoosts

Exceptions
----------

.. autoclass:: FieldConfigurationError
.. autoclass:: UnknownFieldError
